/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - TypedAttribute.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/

package org.snmp4j.agent.mo.jmx.types;

import java.io.*;

import org.snmp4j.smi.Variable;
import javax.management.*;

/**
 * A <code>TypedAttribute</code> is the combination of a attribute name
 * and a <code>Class</code> instance denoting the name and type of a MBean
 * attribute value. Various transformation methods provide mappings to and from
 * SNMP values.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class TypedAttribute
    implements Serializable, SMITransformType, TransformType
{

  private String name;
  private Class type;

  public TypedAttribute(String name, String type) throws ClassNotFoundException {
    this.name = name;
    this.type = Class.forName(type);
  }

  public TypedAttribute(String name, Class type) {
    this.name = name;
    this.type = type;
  }

  public String getName() {
    return name;
  }

  public Class getType() {
    return type;
  }

  public void transformObject2SMI(Object object, Variable value) {
    SMIVariant colVariant = new SMIVariant(value);
    colVariant.setValue(object);
  }

  public Object transformSMI2Object(Variable value) {
    SMIVariant smiVariant = new SMIVariant(value);
    return smiVariant.getValue(type);
  }

  public Object transformFromNative(Object nativeValue, ObjectName objectName) {
    return nativeValue;
  }

  public Object transformToNative(Object transformedValue,
                                  Object oldNativeValue, ObjectName objectName) {
    return transformedValue;
  }

  public boolean isNativeValueAlwaysNeeded() {
    return false;
  }

}
